'''
Created on 2022-04-21

@author: wf
'''

class Version(object):
    '''
    Version handling for pyGenericSpreadSheet
    '''
    version='0.1.5'
    date = '2022-04-21'
    updated = '2022-07-31'
    name='pyGenericSpreadSheet'
    description='python API providing generic Access to specific Spreadsheet backends'